@@ -5,7 +5,7 @@ from PySide.QtCore import *
 from PySide.QtGui import *
 
 # Some global variables
-FceuGuiVersion = "0.0.1-6"
+FceuGuiVersion = "0.0.1-7"
 CommentChar = '#'
 OptionChar =  ' '
 Home = os.path.expanduser("~")
@@ -373,6 +373,17 @@ class ConfigWindow(QMainWindow):
 			self.blurPushButton.setChecked(True)
 		else:
 			self.blurPushButton.setChecked(False)
+	# Fceu cheat
+        self.cheatPushButton = QPushButton("Fceu cheats",self)
+	self.cheatPushButton.setCheckable(True)
+        grid.addWidget(self.cheatPushButton,1,2)
+	if (os.path.isdir(Home + "/.fceultra/cheats")):
+		self.cheatPushButton.setChecked(True)
+	if (os.path.isdir(Home + "/.fceultra/no_cheats")):
+		self.cheatPushButton.setChecked(False)
+	if not os.path.isdir(Home + "/.fceultra/no_cheats"):
+		if not os.path.isdir(Home + "/.fceultra/cheats"):
+			self.cheatPushButton.setEnabled(False)
 	# BPP
 	grid.addWidget(QLabel("<center>Bits per pixel (fs):</center>"), 3, 0)
         self.comboBPP = QComboBox(self)
@@ -422,6 +433,17 @@ class ConfigWindow(QMainWindow):
         if self.blurPushButton.isChecked():
            self.gui_opts["tv_blur"] = "true"
         else: self.gui_opts["tv_blur"] = "false" 
+        if self.cheatPushButton.isChecked():
+		if not (os.path.isdir(Home + "/.fceultra/cheats")):
+			if (os.path.isdir(Home + "/.fceultra/no_cheats")):
+				mv_cmd = 'mv ' + Home + '/.fceultra/no_cheats ' + Home + '/.fceultra/cheats'
+				os.system(mv_cmd)
+        else:
+		if not (os.path.isdir(Home + "/.fceultra/no_cheats")):
+			if (os.path.isdir(Home + "/.fceultra/cheats")):
+				mv_cmd = 'mv ' + Home + '/.fceultra/cheats ' + Home + '/.fceultra/no_cheats'
+				os.system(mv_cmd)
+		
 	self.gui_opts["bpp"] = self.comboBPP.currentText()
         if RomPath != "":
            self.gui_opts["rom_path"] = RomPath
