@@ -19,7 +19,7 @@ fi
 # Set missing values
 grep ^exec_path $CFG_FILE >/dev/null || echo "exec_path /usr/bin" >> $CFG_FILE
 grep ^exit_after_launch $CFG_FILE >/dev/null || echo "exit_after_launch false" >> $CFG_FILE
-grep ^rom_path $CFG_FILE >/dev/null || echo "rom_path notset" >> $CFG_FILE
+grep "^rom_path " $CFG_FILE >/dev/null || echo "rom_path notset" >> $CFG_FILE
 grep ^sound $CFG_FILE >/dev/null || echo "sound true" >> $CFG_FILE
 grep ^bpp $CFG_FILE >/dev/null || echo "bpp 16" >> $CFG_FILE
 grep ^fs $CFG_FILE >/dev/null || echo "fs true" >> $CFG_FILE
